@@ -23,7 +23,7 @@
 #' @param counts Should counts be added?
 #' @param counts_weighted If \code{counts} is TRUE: Should counts be weighted by the case weights? If TRUE, the sum of \code{w} is returned by group.
 #' @param v_labels If FALSE, return group centers of \code{v} instead of labels. Only relevant for types "response", "predicted" or "residual" and if \code{v} is being binned. In that case useful if e.g. different flashlights use different data sets and bin labels would not match.
-#' @param pred Optional vector with predictions (after application of inverse link). Can be used to avoid recalculation of predictions over and over if the functions is to be repeatedly called for different \code{v} and predictions are computationally expensive to make. Only relevant for \code{type = "predicted"} and \code{type = "ale"}.
+#' @param pred Optional vector with predictions (after application of inverse link). Can be used to avoid recalculation of predictions over and over if the functions is to be repeatedly called for different \code{v} and predictions are computationally expensive to make. Only relevant for \code{type = "predicted"} and \code{type = "ale"}. Not implemented for multiflashlight.
 #' @param pd_evaluate_at Vector with values of \code{v} used to evaluate the profile. Only relevant for type = "partial dependence" and "ale".
 #' @param pd_grid A \code{data.frame} with grid values, e.g. generated by \code{expand.grid}. Only used for type = "partial dependence".
 #' @param pd_indices A vector of row numbers to consider in calculating partial dependence profiles. Only used for type = "partial dependence" and "ale".
@@ -53,13 +53,10 @@
 #' Apley D. W. (2016). Visualizing the effects of predictor variables in black box supervised learning models.
 #'
 #' @examples
-#' fit_full <- lm(Sepal.Length ~ ., data = iris)
-#' mod_full <- flashlight(model = fit_full, label = "full", data = iris, y = "Sepal.Length")
-#' light_profile(mod_full, v = "Species")
-#' light_profile(mod_full, v = "Species", type = "response")
-#' light_profile(mod_full, v = "Species", stats = "quartiles")
-#' light_profile(mod_full, v = "Petal.Width", type = "residual")
-#' light_profile(mod_full, v = "Petal.Width", pd_evaluate_at = 2:4)
+#' fit <- lm(Sepal.Length ~ ., data = iris)
+#' fl <- flashlight(model = fit, label = "iris", data = iris, y = "Sepal.Length")
+#' light_profile(fl, v = "Species")
+#' light_profile(fl, v = "Petal.Width", type = "residual")
 #' @seealso \code{\link{light_effects}}, \code{\link{plot.light_profile}}.
 light_profile <- function(x, ...) {
   UseMethod("light_profile")
@@ -110,7 +107,7 @@ light_profile.flashlight <- function(x, v = NULL, data = NULL, by = x$by,
     stop("Wrong number of predicted values passed.")
   }
   if (type == "ale" && stats == "quartiles") {
-    stop("The cumsum step of ALE does not make sense for quartiles.")
+    stop("The cumsum step of ALE does not make sense for quartiles, so this option is not available.")
   }
 
   # Update flashlight
@@ -153,7 +150,7 @@ light_profile.flashlight <- function(x, v = NULL, data = NULL, by = x$by,
   }
 
   # Aggregate predicted values
-  if (type != "ale") {
+  if (type != "ale") { # ale is already aggregated
     agg <- grouped_stats(data = data, x = value_name, w = x$w, by = c(by, v),
                          stats = stats, counts = counts,
                          counts_weighted = counts_weighted,
@@ -184,6 +181,10 @@ light_profile.multiflashlight <- function(x, v = NULL, data = NULL,
                                           pd_evaluate_at = NULL, pd_grid = NULL, ...) {
   cut_type <- match.arg(cut_type)
 
+  if ("pred" %in% names(list(...))) {
+    stop("'pred' not implemented for multiflashlight")
+  }
+
   if (is.null(breaks) && is.null(pd_evaluate_at) && is.null(pd_grid)) {
     breaks <- common_breaks(x = x, v = v, data = data, breaks = breaks,
                             n_bins = n_bins, cut_type = cut_type)
